==> plg_cookieconsent_3.x_5.1.0.zip: cookieconsent.php <==
<?php
/**
 * @package    cookieconsent
 *
 * @author     christophf <your@email.com>
 * @copyright  A copyright
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 * @link       http://your.url.com
 */

use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Document\HtmlDocument;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\Database\DatabaseDriver;

defined('_JEXEC') or die;

/**
 * CookieConsent plugin.
 *
 * @package   cookieconsent
 * @since     1.0.0
 */
class plgSystemCookieconsent extends CMSPlugin
{
	/**
	 * Application object
	 *
	 * @var    CMSApplication
	 * @since  1.0.0
	 */
	protected $app;

    /**
     * Domain where our app lives
     *
     * @var string
     * @since 1.0.0
     */
	protected $ckmnstrDomain = 'ckmnstr.de';

	/**
	 * Database object
	 *
	 * @var    DatabaseDriver
	 * @since  1.0.0
	 */
	protected $db;

    /**
     * Document Object
     *
     * @var HtmlDocument
     * @since 1.0.0
     */
	protected $doc;

	/**
	 * Affects constructor behavior. If true, language files will be loaded automatically.
	 *
	 * @var    boolean
	 * @since  1.0.0
	 */
	protected $autoloadLanguage = true;

	/**
	 * onAfterRender.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	public function onAfterDispatch()
	{
		// Access to plugin parameters
        if (!$this->checkGates()) return;

        $consents = $this->params->get('consents', []);
        $id = $this->params->get('id', null);
        $this->doc = $this->app->getDocument();

        $cdnDomain = "https://cdn.$this->ckmnstrDomain";
        $version = '2.0.0';

        $this->doc->addStyleSheet($cdnDomain . '/css/app.latest.css', [
            'version' => $version,
        ]);
        $this->doc->addScript($cdnDomain . '/js/chunk-vendors.latest.js', [
            'version' => $version,
        ]);
        $this->doc->addScript($cdnDomain . '/js/app.latest.js', [
            'version' => $version,
        ]);

        $this->doc->addCustomTag("<script type='text/javascript'>
          document.addEventListener('DOMContentLoaded', function() {
            CookieConsent({
              basePath: '$cdnDomain/',
              appId: '$id',
            });
          });
</script>");

        foreach ($consents as $consent) {
            if (preg_match('/^https?:\/\//', $consent->script)) {
                $tag = $this->generateScriptTag($consent);
            } else {
                $tag = $this->generateScriptDeclaration($consent);
            }

            $this->addScriptTag($tag);
        }

        if ($this->params->get('handle_iframes', false)) {
            $this->doc->addStyleDeclaration('
            :root {
                --cc-accent-background: #194e9a;
            }
            .cc_banner {
                box-shadow: 0 0 7px rgba(0, 0, 0, 0.2), 0 -2px 10px rgba(0, 0, 0, 0.07);
            }');
        }
	}

    protected function generateScriptDeclaration($consent): string
    {
        return "<script type='text/plain' data-type='text/javascript' data-consent='$consent->consent'>$consent->script</script>";
    }

    protected function generateScriptTag($consent): string
    {
        return "<script type='text/plain' data-type='text/javascript' data-consent='$consent->consent' data-src='$consent->script'></script>";
    }

    protected function addScriptTag(string $tag): void
    {
        $this->doc->addCustomTag($tag);
    }

    public function onAfterRender()
    {
        if (!$this->params->get('handle_iframes', false)) return;


        if (!$this->checkGates()) return;

        $content = $this->app->getBody();

        if (!$this->hasIframes($content)) return;

        if (!$GLOBALS['charset_injected']) {
            if (!preg_match('/<meta http-equiv="Content-Type" content="text\/html; charset=utf-8"\s?\/?>/i', $content)) {
                $content = preg_replace('/<meta charset="utf-8"\s?\/?>/', '<meta charset="utf-8" /><meta http-equiv="Content-Type" content="text/html; charset=utf-8" />', $content, 1);
            }
            $GLOBALS['charset_injected'] = true;
        }

        $dom = new DOMDocument;
        $dom->resolveExternals = true;
        $dom->substituteEntities = false;
        @$dom->loadHTML($content);

        /** @var DOMNodeList $iframes */
        $iframes = $dom->getElementsByTagName('iframe');

        /** @var DOMElement $iframe */
        foreach ($iframes as $iframe) {
            $src = $this->noCookieUrl($iframe->getAttribute('src'));

            if (strpos($src, 'youtu') !== false ||
                strpos($src, 'vimeo') !== false
            ) {
                $iframe->setAttribute('data-src', $src);
                $vendorId = $this->getVendorId($src);

                $class = $iframe->getAttribute('class');

                $classList = array_filter([$class, 'privacy-iframe', $this->getIframeClass($vendorId)]);

                $iframe->setAttribute('class', implode(' ', $classList));
                $iframe->setAttribute('style',
                    'background-image: url(' . $this->getThumbnail($src, $vendorId) . ')');

                $iframe->removeAttribute('src');
            }
        }

        $this->app->setBody($dom->saveHTML());
    }

    protected function noCookieUrl(string $src): string
    {
        return preg_replace('/youtube\./', 'youtube-nocookie.', $src);
    }

    protected function getVendorId(string $src): ?int
    {
        if (strpos($src, 'youtu') !== false) {
            return 1;
        } else if (strpos($src, 'vimeo') !== false) {
           return 2;
        }
        return null;
    }

    protected function getIframeClass(int $vendorId): ?string
    {
        if ($vendorId === 1) {
            $vendor = 'youtube';
        } else if ($vendorId === 2) {
            $vendor = 'vimeo';
        } else {
            return null;
        }

        return "vendor-$vendor";
    }

    protected function getThumbnail(string $src, int $vendorId)
    {
        $videoId = $this->getVideoId($src, $vendorId);
        return "https://i.ytimg.com/vi/$videoId/maxresdefault.jpg";
    }

    protected function getVideoId(string $src, int $vendorId): ?string
    {
        $parts = parse_url($src);
        if (isset($parts['query'])) {
            parse_str($parts['query'], $query);
        } else {
            $query = null;
        }

        if ($vendorId === 1) {
            // Youtube
            return substr($parts['path'], 7);
        } else if ($vendorId === 2) {
            // vimeo
            return substr($parts['path'], 1);
        } else if ($vendorId === 3) {
            // Facebook
            if ($query) {
                return $query['v'];
            } else if (preg_match('/(?:videos\/|v=)([\d]*)/', $this->url, $matches)) {
                return $matches[1];
            }
        }

        return '';
    }

    protected function hasIframes(string $content): bool
    {
        return strpos($content, '<iframe') !== false;
    }

    protected function checkGates(): bool
    {
        if ($this->app->isClient('administrator')) return false;

        if ($this->isEditPage()) return false;

        return true;
    }

    protected function isEditPage(): bool
    {
        $input = $this->app->input;

        $option = $input->get('option');

        // always return false for these components
        if (in_array($option, ['com_rsevents', 'com_rseventspro']))
        {
            return false;
        }

        $task = $input->get('task');

        if (strpos($task, '.') !== false)
        {
            $task = explode('.', $task);
            $task = array_pop($task);
        }

        $view = $input->get('view');

        if (strpos($view, '.') !== false)
        {
            $view = explode('.', $view);
            $view = array_pop($view);
        }

        return
            (
                in_array($option, ['com_contentsubmit', 'com_cckjseblod'])
                || ($option == 'com_comprofiler' && in_array($task, ['', 'userdetails']))
                || in_array($task, ['edit', 'form', 'submission'])
                || in_array($view, ['edit', 'form'])
                || in_array($input->get('do'), ['edit', 'form'])
                || in_array($input->get('layout'), ['edit', 'form', 'write'])
            );
    }
}

==> plg_cookieconsent_3.x_5.1.1.zip: cookieconsent.php <==
<?php
/**
 * @package    cookieconsent
 *
 * @author     christophf <your@email.com>
 * @copyright  A copyright
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 * @link       http://your.url.com
 */

use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Document\HtmlDocument;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\Database\DatabaseDriver;

defined('_JEXEC') or die;

/**
 * CookieConsent plugin.
 *
 * @package   cookieconsent
 * @since     1.0.0
 */
class plgSystemCookieconsent extends CMSPlugin
{
	/**
	 * Application object
	 *
	 * @var    CMSApplication
	 * @since  1.0.0
	 */
	protected $app;

    /**
     * Domain where our app lives
     *
     * @var string
     * @since 1.0.0
     */
	protected $ckmnstrDomain = 'ckmnstr.de';

	/**
	 * Database object
	 *
	 * @var    DatabaseDriver
	 * @since  1.0.0
	 */
	protected $db;

    /**
     * Document Object
     *
     * @var HtmlDocument
     * @since 1.0.0
     */
	protected $doc;

	/**
	 * Affects constructor behavior. If true, language files will be loaded automatically.
	 *
	 * @var    boolean
	 * @since  1.0.0
	 */
	protected $autoloadLanguage = true;

	/**
	 * onAfterRender.
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	public function onAfterDispatch()
	{
		// Access to plugin parameters
        if (!$this->checkGates()) return;

        $consents = $this->params->get('consents', []);
        $id = $this->params->get('id', null);
        $this->doc = $this->app->getDocument();

        $cdnDomain = "https://cdn.$this->ckmnstrDomain";
        $version = '2.0.1';

        $this->doc->addStyleSheet($cdnDomain . '/css/app.latest.css', [
            'version' => $version,
        ]);
        $this->doc->addScript($cdnDomain . '/js/chunk-vendors.latest.js', [
            'version' => $version,
        ]);
        $this->doc->addScript($cdnDomain . '/js/app.latest.js', [
            'version' => $version,
        ]);

        $this->doc->addCustomTag("<script type='text/javascript'>
          document.addEventListener('DOMContentLoaded', function() {
            CookieConsent({
              basePath: '$cdnDomain/',
              appId: '$id',
            });
          });
</script>");

        foreach ($consents as $consent) {
            if (preg_match('/^https?:\/\//', $consent->script)) {
                $tag = $this->generateScriptTag($consent);
            } else {
                $tag = $this->generateScriptDeclaration($consent);
            }

            $this->addScriptTag($tag);
        }

        if ($this->params->get('handle_iframes', false)) {
            $this->doc->addStyleDeclaration('
            :root {
                --cc-accent-background: #194e9a;
            }
            .cc_banner {
                box-shadow: 0 0 7px rgba(0, 0, 0, 0.2), 0 -2px 10px rgba(0, 0, 0, 0.07);
            }
            .privacy-iframe {
                background: none center/cover;
            }');
        }
	}

    protected function generateScriptDeclaration($consent): string
    {
        return "<script type='text/plain' data-type='text/javascript' data-consent='$consent->consent'>$consent->script</script>";
    }

    protected function generateScriptTag($consent): string
    {
        return "<script type='text/plain' data-type='text/javascript' data-consent='$consent->consent' data-src='$consent->script'></script>";
    }

    protected function addScriptTag(string $tag): void
    {
        $this->doc->addCustomTag($tag);
    }

    public function onAfterRender()
    {
        if (!$this->params->get('handle_iframes', false)) return;


        if (!$this->checkGates()) return;

        $content = $this->app->getBody();

        if (!$this->hasIframes($content)) return;

        if (!$GLOBALS['charset_injected']) {
            if (!preg_match('/<meta http-equiv="Content-Type" content="text\/html; charset=utf-8"\s?\/?>/i', $content)) {
                $content = preg_replace('/<meta charset="utf-8"\s?\/?>/', '<meta charset="utf-8" /><meta http-equiv="Content-Type" content="text/html; charset=utf-8" />', $content, 1);
            }
            $GLOBALS['charset_injected'] = true;
        }

        $dom = new DOMDocument;
        $dom->resolveExternals = true;
        $dom->substituteEntities = false;
        @$dom->loadHTML($content);

        /** @var DOMNodeList $iframes */
        $iframes = $dom->getElementsByTagName('iframe');

        /** @var DOMElement $iframe */
        foreach ($iframes as $iframe) {
            $src = $this->noCookieUrl($iframe->getAttribute('src'));

            if (strpos($src, 'youtu') !== false ||
                strpos($src, 'vimeo') !== false
            ) {
                $iframe->setAttribute('data-src', $src);
                $iframe->setAttribute('data-src', $src);
                $vendorId = $this->getVendorId($src);

                $class = $iframe->getAttribute('class');

                $classList = array_filter([$class, 'privacy-iframe']);

                $iframe->setAttribute('data-consent', $this->getVendorName($vendorId));

                $iframe->setAttribute('class', implode(' ', $classList));
                $iframe->setAttribute('style',
                    'background-image: url(' . $this->getThumbnail($src, $vendorId) . ')');

                $iframe->removeAttribute('src');
            }
        }

        $this->app->setBody($dom->saveHTML());
    }

    protected function noCookieUrl(string $src): string
    {
        return preg_replace('/youtube\./', 'youtube-nocookie.', $src);
    }

    protected function getVendorId(string $src): ?int
    {
        if (strpos($src, 'youtu') !== false) {
            return 1;
        } else if (strpos($src, 'vimeo') !== false) {
           return 2;
        }
        return null;
    }

    protected function getVendorName(int $vendorId): ?string
    {
        if ($vendorId === 1) {
            return 'youtube';
        } else if ($vendorId === 2) {
            return 'vimeo';
        }

        return null;
    }

    protected function getThumbnail(string $src, int $vendorId)
    {
        $videoId = $this->getVideoId($src, $vendorId);
        return "https://i.ytimg.com/vi/$videoId/maxresdefault.jpg";
    }

    protected function getVideoId(string $src, int $vendorId): ?string
    {
        $parts = parse_url($src);
        if (isset($parts['query'])) {
            parse_str($parts['query'], $query);
        } else {
            $query = null;
        }

        if ($vendorId === 1) {
            // Youtube
            return substr($parts['path'], 7);
        } else if ($vendorId === 2) {
            // vimeo
            return substr($parts['path'], 1);
        } else if ($vendorId === 3) {
            // Facebook
            if ($query) {
                return $query['v'];
            } else if (preg_match('/(?:videos\/|v=)([\d]*)/', $this->url, $matches)) {
                return $matches[1];
            }
        }

        return '';
    }

    protected function hasIframes(string $content): bool
    {
        return strpos($content, '<iframe') !== false;
    }

    protected function checkGates(): bool
    {
        if ($this->app->isClient('administrator')) return false;

        if ($this->isEditPage()) return false;

        return true;
    }

    protected function isEditPage(): bool
    {
        $input = $this->app->input;

        $option = $input->get('option');

        // always return false for these components
        if (in_array($option, ['com_rsevents', 'com_rseventspro']))
        {
            return false;
        }

        $task = $input->get('task');

        if (strpos($task, '.') !== false)
        {
            $task = explode('.', $task);
            $task = array_pop($task);
        }

        $view = $input->get('view');

        if (strpos($view, '.') !== false)
        {
            $view = explode('.', $view);
            $view = array_pop($view);
        }

        return
            (
                in_array($option, ['com_contentsubmit', 'com_cckjseblod'])
                || ($option == 'com_comprofiler' && in_array($task, ['', 'userdetails']))
                || in_array($task, ['edit', 'form', 'submission'])
                || in_array($view, ['edit', 'form'])
                || in_array($input->get('do'), ['edit', 'form'])
                || in_array($input->get('layout'), ['edit', 'form', 'write'])
            );
    }
}
